@@ -13,7 +13,7 @@ import ClassyPrelude hiding (undefined)
 import Test.QuickCheck.Arbitrary
 import Prelude (undefined)
 import Control.Monad.Trans.Writer (tell, Writer, runWriter)
-import Control.Concurrent (throwTo, threadDelay, forkIO)
+import Control.Concurrent (forkIO)
 import Control.Exception (throw)
 import qualified Data.Set as Set
 import qualified Data.HashSet as HashSet
@@ -61,7 +61,6 @@ mapProps map' pack' dummy f g = do
 concatMapProps :: ( MonoFoldable c
                   , IsSequence c
                   , Eq c
-                  , MonoFoldableMonoid c
                   , Arbitrary c
                   , Show c
                   )
@@ -191,7 +190,8 @@ chunkProps dummy = do
 stripSuffixProps :: ( Eq c
                     , Show c
                     , Arbitrary c
-                    , EqSequence c
+                    , IsSequence c
+                    , Eq (Element c)
                     )
                  => c
                  -> Spec
@@ -238,7 +238,8 @@ compareLengthProps dummy = do
         compare (length c) i == compareLength (c `asTypeOf` dummy) i
 
 prefixProps :: ( Eq c
-               , EqSequence c
+               , IsSequence c
+               , Eq (Element c)
                , Arbitrary c
                , Show c
                )
@@ -373,36 +374,39 @@ main = hspec $ do
         describe "Vector" $ prefixProps (undefined :: Vector Int)
         describe "UVector" $ prefixProps (undefined :: UVector Int)
         describe "Seq" $ prefixProps (undefined :: Seq Int)
+    {- This tests depend on timing and are unreliable. Instead, we're relying
+       on the test suite in safe-exceptions itself.
     describe "any exceptions" $ do
         it "catchAny" $ do
             failed <- newIORef 0
             tid <- forkIO $ do
                 catchAny
-                    (Control.Concurrent.threadDelay 20000)
+                    (threadDelay 20000)
                     (const $ writeIORef failed 1)
                 writeIORef failed 2
-            Control.Concurrent.threadDelay 10000
-            Control.Concurrent.throwTo tid DummyException
-            Control.Concurrent.threadDelay 50000
+            threadDelay 10000
+            throwTo tid DummyException
+            threadDelay 50000
             didFail <- readIORef failed
             liftIO $ didFail `shouldBe` (0 :: Int)
         it "tryAny" $ do
             failed <- newIORef False
             tid <- forkIO $ do
-                _ <- tryAny $ Control.Concurrent.threadDelay 20000
+                _ <- tryAny $ threadDelay 20000
                 writeIORef failed True
-            Control.Concurrent.threadDelay 10000
-            Control.Concurrent.throwTo tid DummyException
-            Control.Concurrent.threadDelay 50000
+            threadDelay 10000
+            throwTo tid DummyException
+            threadDelay 50000
             didFail <- readIORef failed
             liftIO $ didFail `shouldBe` False
         it "tryAnyDeep" $ do
-            eres <- tryAnyDeep $ return $ throw DummyException
+            eres <- tryAny $ return $!! impureThrow DummyException
             case eres of
                 Left e
                     | Just DummyException <- fromException e -> return ()
                     | otherwise -> error "Expected a DummyException"
                 Right () -> error "Expected an exception" :: IO ()
+    -}
     it "basic DList functionality" $
         (toList $ asDList $ mconcat
             [ fromList [1, 2]
@@ -411,6 +415,13 @@ main = hspec $ do
             , fromList $ applyDList (singleton 5 ++ singleton 6) [7, 8]
             ]) `shouldBe` [1..8 :: Int]
 
+    describe "Data.ByteVector" $ do
+        prop "toByteVector" $ \ws ->
+            (otoList . toByteVector . fromList $ ws) `shouldBe` ws
+
+        prop "fromByteVector" $ \ws ->
+            (otoList . fromByteVector . fromList $ ws) `shouldBe` ws
+
 data DummyException = DummyException
     deriving (Show, Typeable)
 instance Exception DummyException
